@@ -59,6 +59,7 @@ from sqlalchemy import exc as sa_exc
 import neutron.plugins.ml2.rpc as rpc
 
 # Calico imports.
+from networking_calico.common import config as calico_config
 from networking_calico.compat import cfg
 from networking_calico.compat import constants
 from networking_calico.compat import db_exc
@@ -66,6 +67,7 @@ from networking_calico.compat import lockutils
 from networking_calico.compat import log
 from networking_calico.compat import plugin_dir
 from networking_calico import datamodel_v1
+from networking_calico import datamodel_v2
 from networking_calico import datamodel_v3
 from networking_calico import etcdv3
 from networking_calico.logutils import logging_exceptions
@@ -287,7 +289,7 @@ class CalicoMechanismDriver(mech_agent.SimpleAgentMechanismDriverBase):
             try:
                 user_domain_name = authcfg.user_domain_name
             except cfg.NoSuchOptError:
-                user_domain_name = 'default'
+                user_domain_name = 'Default'
                 LOG.debug("authcfg[user_domain_name] fallback = %s",
                           user_domain_name)
 
@@ -308,7 +310,7 @@ class CalicoMechanismDriver(mech_agent.SimpleAgentMechanismDriverBase):
             try:
                 project_domain_name = authcfg.project_domain_name
             except cfg.NoSuchOptError:
-                project_domain_name = 'default'
+                project_domain_name = 'Default'
                 LOG.debug("authcfg[project_domain_name] fallback = %s",
                           project_domain_name)
 
@@ -363,12 +365,12 @@ class CalicoMechanismDriver(mech_agent.SimpleAgentMechanismDriverBase):
             )
 
             # Elector, for performing leader election.
-            self.elector = Elector(
-                server_id=cfg.CONF.calico.elector_name,
-                election_key=datamodel_v1.NEUTRON_ELECTION_KEY,
-                interval=MASTER_REFRESH_INTERVAL,
-                ttl=MASTER_TIMEOUT,
-            )
+            self.elector = Elector(cfg.CONF.calico.elector_name,
+                                   datamodel_v2.neutron_election_key(
+                                       calico_config.get_region_string()),
+                                   old_key=datamodel_v1.NEUTRON_ELECTION_KEY,
+                                   interval=MASTER_REFRESH_INTERVAL,
+                                   ttl=MASTER_TIMEOUT)
 
             self._my_pid = current_pid
 
@@ -1042,6 +1044,7 @@ class CalicoMechanismDriver(mech_agent.SimpleAgentMechanismDriverBase):
             if rewrite_cluster_info:
                 LOG.info("New ClusterInformation: %s", cluster_info)
                 if datamodel_v3.put("ClusterInformation",
+                                    datamodel_v3.NOT_NAMESPACED,
                                     "default",
                                     cluster_info,
                                     mod_revision=ci_mod_revision):
@@ -1087,6 +1090,7 @@ class CalicoMechanismDriver(mech_agent.SimpleAgentMechanismDriverBase):
             if rewrite_felix_config:
                 LOG.info("New FelixConfiguration: %s", felix_config)
                 if datamodel_v3.put("FelixConfiguration",
+                                    datamodel_v3.NOT_NAMESPACED,
                                     "default",
                                     felix_config,
                                     mod_revision=fc_mod_revision):
